# HG changeset patch
# Node ID 2b1e99d4d1a7
# Parent  366e634bb9fe
diff --git a/libpurple/protocols/bonjour/bonjour_ft.c b/libpurple/protocols/bonjour/bonjour_ft.c
--- a/libpurple/protocols/bonjour/bonjour_ft.c
+++ b/libpurple/protocols/bonjour/bonjour_ft.c
@@ -494,7 +494,7 @@ xep_si_parse(PurpleConnection *pc, Purpl
  * distinct buddies with the same ipv6 link local address on two distinct
  * interfaces. Unfortunately XEP-0065 does not seem to specify how to deal with
  * link local ip addresses properly...
- * However, in practice the possiblity for such a conflict is relatively low
+ * However, in practice the possibility for such a conflict is relatively low
  * (2011 - might be different in the future though?).
  *
  * @param host		ipv4 or ipv6 address string
diff --git a/libpurple/protocols/bonjour/mdns_common.c b/libpurple/protocols/bonjour/mdns_common.c
--- a/libpurple/protocols/bonjour/mdns_common.c
+++ b/libpurple/protocols/bonjour/mdns_common.c
@@ -124,7 +124,7 @@ static GSList *generate_presence_txt_rec
 	ret = _add_txt_record(ret, "status", data->status);
 	ret = _add_txt_record(ret, "node", "libpurple");
 	ret = _add_txt_record(ret, "ver", VERSION);
-	/* Currently always set to "!" since we don't support AV and wont ever be in a conference */
+	/* Currently always set to "!" since we don't support AV and won't ever be in a conference */
 	ret = _add_txt_record(ret, "vc", data->vc);
 	if (email != NULL && *email != '\0') {
 		ret = _add_txt_record(ret, "email", email);
diff --git a/libpurple/protocols/bonjour/xmpp.c b/libpurple/protocols/bonjour/xmpp.c
--- a/libpurple/protocols/bonjour/xmpp.c
+++ b/libpurple/protocols/bonjour/xmpp.c
@@ -654,7 +654,7 @@ bonjour_xmpp_stream_started(BonjourXMPPC
 			}
 		}
 
-		/* We don't want to recieve anything else */
+		/* We don't want to receive anything else */
 		purple_gio_graceful_close(G_IO_STREAM(bconv->socket),
 		                          G_INPUT_STREAM(bconv->input),
 		                          G_OUTPUT_STREAM(bconv->output));
@@ -826,7 +826,7 @@ static void
 		g_clear_error(&error);
 
 		/* There may be multiple entries for the same IP - one per
-		 * presence recieved (e.g. multiple interfaces).
+		 * presence received (e.g. multiple interfaces).
 		 * We need to make sure that we find the previously used entry.
 		 */
 		tmp = g_slist_find(bb->ips, bb->conversation->ip_link);
@@ -1149,7 +1149,7 @@ bonjour_xmpp_close_conversation(BonjourX
 	}
 
 	/* Cancel any file transfers that are waiting to begin */
-	/* There wont be any transfers if it hasn't been attached to a buddy */
+	/* There won't be any transfers if it hasn't been attached to a buddy */
 	if (bconv->pb != NULL && bd != NULL) {
 		GSList *xfers, *tmp_next;
 		xfers = bd->xfer_lists;
diff --git a/libpurple/protocols/facebook/api.h b/libpurple/protocols/facebook/api.h
--- a/libpurple/protocols/facebook/api.h
+++ b/libpurple/protocols/facebook/api.h
@@ -843,34 +843,34 @@ fb_api_message_free(FbApiMessage *msg);
 
 /**
  * fb_api_presence_dup:
- * @pres: The #FbApiPresence or #NULL.
+ * @presence: The #FbApiPresence or %NULL.
  *
- * Duplicates an #FbApiPresence. If @pres is #NULL, a new zero filled
- * #FbApiPresence is returned. The returned #FbApiPresence should be
- * freed with #fb_api_presence_free() when no longer needed.
+ * Duplicates an #FbApiPresence. If @presence is %NULL, a new zero filled
+ * #FbApiPresence is returned. The returned #FbApiPresence should be freed with
+ * #fb_api_presence_free() when no longer needed.
  *
  * Returns: The new #FbApiPresence.
  */
 FbApiPresence *
-fb_api_presence_dup(const FbApiPresence *pres);
+fb_api_presence_dup(const FbApiPresence *presence);
 
 /**
  * fb_api_presence_reset:
- * @pres: The #FbApiPresence.
+ * @presence: The #FbApiPresence.
  *
  * Resets an #FbApiPresence.
  */
 void
-fb_api_presence_reset(FbApiPresence *pres);
+fb_api_presence_reset(FbApiPresence *presence);
 
 /**
  * fb_api_presence_free:
- * @pres: The #FbApiPresence.
+ * @presence: The #FbApiPresence.
  *
  * Frees all memory used by the #FbApiPresence.
  */
 void
-fb_api_presence_free(FbApiPresence *pres);
+fb_api_presence_free(FbApiPresence *presence);
 
 /**
  * fb_api_thread_dup:
diff --git a/libpurple/protocols/facebook/api.c b/libpurple/protocols/facebook/api.c
--- a/libpurple/protocols/facebook/api.c
+++ b/libpurple/protocols/facebook/api.c
@@ -1743,9 +1743,9 @@ fb_api_cb_publish_ms_event(FbApi *api, J
 }
 
 static void
-fb_api_cb_publish_pt(FbThrift *thft, GSList **press, GError **error)
+fb_api_cb_publish_pt(FbThrift *thft, GSList **presences, GError **error)
 {
-	FbApiPresence *pres;
+	FbApiPresence *api_presence;
 	FbThriftType type;
 	gint16 id;
 	gint32 i32;
@@ -1784,10 +1784,10 @@ fb_api_cb_publish_pt(FbThrift *thft, GSL
 		FB_API_TCHK(id == 2);
 		FB_API_TCHK(fb_thrift_read_i32(thft, &i32));
 
-		pres = fb_api_presence_dup(NULL);
-		pres->uid = i64;
-		pres->active = i32 != 0;
-		*press = g_slist_prepend(*press, pres);
+		api_presence = fb_api_presence_dup(NULL);
+		api_presence->uid = i64;
+		api_presence->active = i32 != 0;
+		*presences = g_slist_prepend(*presences, api_presence);
 
 		fb_util_debug_info("Presence: %" FB_ID_FORMAT " (%d) id: %d",
 		                   i64, i32 != 0, id);
@@ -1849,19 +1849,19 @@ fb_api_cb_publish_p(FbApi *api, GByteArr
 {
 	FbThrift *thft;
 	GError *err = NULL;
-	GSList *press = NULL;
+	GSList *presences = NULL;
 
 	thft = fb_thrift_new(pload, 0);
-	fb_api_cb_publish_pt(thft, &press, &err);
+	fb_api_cb_publish_pt(thft, &presences, &err);
 	g_object_unref(thft);
 
 	if (G_LIKELY(err == NULL)) {
-		g_signal_emit_by_name(api, "presences", press);
+		g_signal_emit_by_name(api, "presences", presences);
 	} else {
 		fb_api_error_emit(api, err);
 	}
 
-	g_slist_free_full(press, (GDestroyNotify) fb_api_presence_free);
+	g_slist_free_full(presences, (GDestroyNotify)fb_api_presence_free);
 }
 
 static void
@@ -3338,27 +3338,27 @@ fb_api_message_free(FbApiMessage *msg)
 }
 
 FbApiPresence *
-fb_api_presence_dup(const FbApiPresence *pres)
+fb_api_presence_dup(const FbApiPresence *presence)
 {
-	if (pres == NULL) {
+	if (presence == NULL) {
 		return g_new0(FbApiPresence, 1);
 	}
 
-	return g_memdup2(pres, sizeof *pres);
+	return g_memdup2(presence, sizeof *presence);
 }
 
 void
-fb_api_presence_reset(FbApiPresence *pres)
+fb_api_presence_reset(FbApiPresence *presence)
 {
-	g_return_if_fail(pres != NULL);
-	memset(pres, 0, sizeof *pres);
+	g_return_if_fail(presence != NULL);
+	memset(presence, 0, sizeof *presence);
 }
 
 void
-fb_api_presence_free(FbApiPresence *pres)
+fb_api_presence_free(FbApiPresence *presence)
 {
-	if (G_LIKELY(pres != NULL)) {
-		g_free(pres);
+	if (G_LIKELY(presence != NULL)) {
+		g_free(presence);
 	}
 }
 
diff --git a/libpurple/protocols/facebook/facebook.c b/libpurple/protocols/facebook/facebook.c
--- a/libpurple/protocols/facebook/facebook.c
+++ b/libpurple/protocols/facebook/facebook.c
@@ -600,10 +600,9 @@ fb_cb_api_messages(FbApi *api, GSList *m
 }
 
 static void
-fb_cb_api_presences(FbApi *api, GSList *press, gpointer data)
+fb_cb_api_presences(FbApi *api, GSList *presences, gpointer data)
 {
 	const gchar *statid;
-	FbApiPresence *pres;
 	FbData *fata = data;
 	gchar uid[FB_ID_STRMAX];
 	GSList *l;
@@ -614,16 +613,16 @@ fb_cb_api_presences(FbApi *api, GSList *
 	gc = fb_data_get_connection(fata);
 	acct = purple_connection_get_account(gc);
 
-	for (l = press; l != NULL; l = l->next) {
-		pres = l->data;
+	for (l = presences; l != NULL; l = l->next) {
+		FbApiPresence *api_presence = l->data;
 
-		if (pres->active) {
+		if (api_presence->active) {
 			pstat = PURPLE_STATUS_AVAILABLE;
 		} else {
 			pstat = PURPLE_STATUS_OFFLINE;
 		}
 
-		FB_ID_TO_STR(pres->uid, uid);
+		FB_ID_TO_STR(api_presence->uid, uid);
 		statid = purple_primitive_get_id_from_type(pstat);
 		purple_protocol_got_user_status(acct, uid, statid, NULL);
 	}
@@ -1174,11 +1173,11 @@ fb_client_tooltip_text(PurpleProtocolCli
                        PurpleNotifyUserInfo *info, gboolean full)
 {
 	const gchar *name;
-	PurplePresence *pres;
+	PurplePresence *presence;
 	PurpleStatus *status;
 
-	pres = purple_buddy_get_presence(buddy);
-	status = purple_presence_get_active_status(pres);
+	presence = purple_buddy_get_presence(buddy);
+	status = purple_presence_get_active_status(presence);
 
 	if (!PURPLE_BUDDY_IS_ONLINE(buddy)) {
 		/* Prevent doubles statues for Offline buddies */
diff --git a/libpurple/protocols/facebook/json.h b/libpurple/protocols/facebook/json.h
--- a/libpurple/protocols/facebook/json.h
+++ b/libpurple/protocols/facebook/json.h
@@ -176,7 +176,7 @@ fb_json_bldr_obj_end(JsonBuilder *bldr);
  * @name: The member name or #NULL.
  * @value: The value.
  *
- * Adds a boolean memeber to the #JsonBuilder.
+ * Adds a boolean member to the #JsonBuilder.
  */
 void
 fb_json_bldr_add_bool(JsonBuilder *bldr, const gchar *name, gboolean value);
@@ -187,7 +187,7 @@ fb_json_bldr_add_bool(JsonBuilder *bldr,
  * @name: The member name or #NULL.
  * @value: The value.
  *
- * Adds a floating point memeber to the #JsonBuilder.
+ * Adds a floating point member to the #JsonBuilder.
  */
 void
 fb_json_bldr_add_dbl(JsonBuilder *bldr, const gchar *name, gdouble value);
@@ -198,7 +198,7 @@ fb_json_bldr_add_dbl(JsonBuilder *bldr, 
  * @name: The member name or #NULL.
  * @value: The value.
  *
- * Adds a integer memeber to the #JsonBuilder.
+ * Adds an integer member to the #JsonBuilder.
  */
 void
 fb_json_bldr_add_int(JsonBuilder *bldr, const gchar *name, gint64 value);
@@ -209,7 +209,7 @@ fb_json_bldr_add_int(JsonBuilder *bldr, 
  * @name: The member name or #NULL.
  * @value: The value.
  *
- * Adds a string memeber to the #JsonBuilder.
+ * Adds a string member to the #JsonBuilder.
  */
 void
 fb_json_bldr_add_str(JsonBuilder *bldr, const gchar *name, const gchar *value);
@@ -221,7 +221,7 @@ fb_json_bldr_add_str(JsonBuilder *bldr, 
  * @format: The format string literal.
  * @...: The arguments for @format.
  *
- * Adds a formatted string memeber to the #JsonBuilder.
+ * Adds a formatted string member to the #JsonBuilder.
  */
 void
 fb_json_bldr_add_strf(JsonBuilder *bldr, const gchar *name,
diff --git a/libpurple/protocols/facebook/util.c b/libpurple/protocols/facebook/util.c
--- a/libpurple/protocols/facebook/util.c
+++ b/libpurple/protocols/facebook/util.c
@@ -295,18 +295,18 @@ fb_util_rand_alnum(guint len)
 }
 
 static void
-fb_util_request_buddy_ok(gpointer *mata, PurpleRequestFields *fields)
+fb_util_request_buddy_ok(gpointer *request_data, PurpleRequestFields *fields)
 {
-	FbUtilRequestBuddyFunc func = mata[0];
+	FbUtilRequestBuddyFunc func = request_data[0];
 	GList *l;
 	GList *select;
-	gpointer data = mata[2];
+	gpointer data = request_data[2];
 	GSList *ret = NULL;
 	PurpleBuddy *bdy;
 	PurpleRequestField *field;
 
 	if (func == NULL) {
-		g_free(mata);
+		g_free(request_data);
 		return;
 	}
 
@@ -322,20 +322,20 @@ fb_util_request_buddy_ok(gpointer *mata,
 	func(ret, data);
 
 	g_slist_free(ret);
-	g_free(mata);
+	g_free(request_data);
 }
 
 static void
-fb_util_request_buddy_cancel(gpointer *mata, PurpleRequestFields *fields)
+fb_util_request_buddy_cancel(gpointer *request_data, PurpleRequestFields *fields)
 {
-	FbUtilRequestBuddyFunc func = mata[1];
-	gpointer data = mata[2];
+	FbUtilRequestBuddyFunc func = request_data[1];
+	gpointer data = request_data[2];
 
 	if (func != NULL) {
 		func(NULL, data);
 	}
 
-	g_free(mata);
+	g_free(request_data);
 }
 
 static gint
@@ -374,7 +374,7 @@ fb_util_request_buddy(PurpleConnection *
 	const gchar *name;
 	gchar *str;
 	GList *items = NULL;
-	gpointer *mata;
+	gpointer *request_data;
 	GSList *buddies;
 	GSList *l;
 	PurpleAccount *acct;
@@ -383,10 +383,10 @@ fb_util_request_buddy(PurpleConnection *
 	PurpleRequestFieldGroup *group;
 	PurpleRequestFields *fields;
 
-	mata = g_new0(gpointer, 3);
-	mata[0] = ok_cb;
-	mata[1] = cancel_cb;
-	mata[2] = data;
+	request_data = g_new0(gpointer, 3);
+	request_data[0] = ok_cb;
+	request_data[1] = cancel_cb;
+	request_data[2] = data;
 
 	acct = purple_connection_get_account(gc);
 	buddies = purple_blist_find_buddies(acct, NULL);
@@ -426,7 +426,7 @@ fb_util_request_buddy(PurpleConnection *
 	                             G_CALLBACK(fb_util_request_buddy_ok),
 				     _("Cancel"),
 	                             G_CALLBACK(fb_util_request_buddy_cancel),
-				     cpar, mata);
+				     cpar, request_data);
 }
 
 void
diff --git a/libpurple/protocols/gg/keymapper.c b/libpurple/protocols/gg/keymapper.c
--- a/libpurple/protocols/gg/keymapper.c
+++ b/libpurple/protocols/gg/keymapper.c
@@ -35,7 +35,7 @@
  * can be also an unique key. We also need a map, to quickly figure out the
  * address for any previously stored value.
  *
- * The naming problem: values becames the keys and vice-versa.
+ * The naming problem: values becomes the keys and vice-versa.
  */
 
 /* TODO
diff --git a/libpurple/protocols/gg/message-prpl.c b/libpurple/protocols/gg/message-prpl.c
--- a/libpurple/protocols/gg/message-prpl.c
+++ b/libpurple/protocols/gg/message-prpl.c
@@ -384,8 +384,10 @@ ggp_message_format_to_gg(PurpleConversat
 		g_match_info_next(match, NULL);
 
 		if (tag == GGP_HTML_TAG_UNKNOWN) {
-			purple_debug_warning("gg", "ggp_message_format_to_gg: "
-				"uknown tag %s\n", tag_str);
+			purple_debug_warning(
+				"gg",
+				"ggp_message_format_to_gg: unknown tag %s",
+				tag_str);
 		}
 
 		/* closing *all* formatting-related tags (GG11 weirdness)
@@ -610,8 +612,10 @@ ggp_message_format_to_gg(PurpleConversat
 		} else if (tag == GGP_HTML_TAG_A || tag == GGP_HTML_TAG_EOM) {
 			/* do nothing */
 		} else if (tag == GGP_HTML_TAG_UNKNOWN) {
-			purple_debug_warning("gg", "ggp_message_format_to_gg: "
-				"uknown tag %s\n", tag_str);
+			purple_debug_warning(
+				"gg",
+				"ggp_message_format_to_gg: unknown tag %s",
+				tag_str);
 		} else {
 			purple_debug_error("gg", "ggp_message_format_to_gg: "
 				"not handled tag %s\n", tag_str);
@@ -628,7 +632,7 @@ ggp_message_format_to_gg(PurpleConversat
 			"end of message not reached\n");
 	}
 
-	/* releasing fonts recources */
+	/* releasing fonts resources */
 	ggp_font_free(font_new);
 	ggp_font_free(font_current);
 	ggp_font_free(font_base);
diff --git a/libpurple/protocols/jabber/auth.c b/libpurple/protocols/jabber/auth.c
--- a/libpurple/protocols/jabber/auth.c
+++ b/libpurple/protocols/jabber/auth.c
@@ -219,7 +219,7 @@ static void auth_old_result_cb(JabberStr
 					(err_code = purple_xmlnode_get_attrib(error, "code")) &&
 					purple_strequal(err_code, "401")) {
 			reason = PURPLE_CONNECTION_ERROR_AUTHENTICATION_FAILED;
-			/* Clear the pasword if it isn't being saved */
+			/* Clear the password if it isn't being saved */
 			if(!purple_account_get_remember_password(account)) {
 				PurpleCredentialManager *manager = NULL;
 
diff --git a/libpurple/protocols/jabber/caps.h b/libpurple/protocols/jabber/caps.h
--- a/libpurple/protocols/jabber/caps.h
+++ b/libpurple/protocols/jabber/caps.h
@@ -76,7 +76,7 @@ void jabber_caps_uninit(void);
 gboolean jabber_caps_exts_known(const JabberCapsClientInfo *info, char **exts);
 
 /**
- * Main entity capabilites function to get the capabilities of a contact.
+ * Main entity capabilities function to get the capabilities of a contact.
  *
  * The callback will be called synchronously if we already have the
  * capabilities for the specified (node,ver,hash) (and, if exts are specified,
diff --git a/libpurple/protocols/jabber/ibb.c b/libpurple/protocols/jabber/ibb.c
--- a/libpurple/protocols/jabber/ibb.c
+++ b/libpurple/protocols/jabber/ibb.c
@@ -75,7 +75,7 @@ jabber_ibb_session_create_from_xmlnode(J
 	sess->id = g_strdup(id);
 	sess->block_size = atoi(block_size);
 	/* if we create a session from an incoming <open/> request, it means the
-	  session is immediatly open... */
+	  session is immediately open... */
 	sess->state = JABBER_IBB_SESSION_OPENED;
 
 	return sess;
diff --git a/libpurple/protocols/jabber/jabber.h b/libpurple/protocols/jabber/jabber.h
--- a/libpurple/protocols/jabber/jabber.h
+++ b/libpurple/protocols/jabber/jabber.h
@@ -139,8 +139,8 @@ struct _JabberStream
 	 *    roster push.
 	 * 3. We receive this roster push and modify our local blist.  This
 	 *    triggers us to send a roster add for group B.
-	 * 4. The server recieves our earlier roster add for group A and sends
-	 *    us a roster push.
+	 * 4. The server receives our earlier roster add for group A and sends us a
+	 *    roster push.
 	 * 5. We receive this roster push and modify our local blist.  This
 	 *    triggers us to send a roster add for group A.
 	 * 6. The server receives our earlier roster add for group B and sends
diff --git a/libpurple/protocols/jabber/jabber.c b/libpurple/protocols/jabber/jabber.c
--- a/libpurple/protocols/jabber/jabber.c
+++ b/libpurple/protocols/jabber/jabber.c
@@ -1592,7 +1592,7 @@ jabber_unregister_account(PurpleProtocol
 
 /* TODO: As Will pointed out in IRC, after being notified by the core to
  * shutdown, we should async. wait for the server to send us the stream
- * termination before destorying everything. That seems like it would require
+ * termination before destroying everything. That seems like it would require
  * changing the semantics of protocol's close(), so it's a good idea for 3.0.0.
  */
 void jabber_close(PurpleConnection *gc)
@@ -2736,7 +2736,7 @@ char *jabber_parse_error(JabberStream *j
 			text = _("Authorization mechanism too weak");
 		} else if(purple_xmlnode_get_child(packet, "not-authorized")) {
 			SET_REASON(PURPLE_CONNECTION_ERROR_AUTHENTICATION_FAILED);
-			/* Clear the pasword if it isn't being saved */
+			/* Clear the password if it isn't being saved */
 			if (!purple_account_get_remember_password(purple_connection_get_account(js->gc))) {
 				PurpleAccount *account = purple_connection_get_account(js->gc);
 				PurpleCredentialManager *manager = NULL;
diff --git a/libpurple/protocols/jabber/jingle/rtp.c b/libpurple/protocols/jabber/jingle/rtp.c
--- a/libpurple/protocols/jabber/jingle/rtp.c
+++ b/libpurple/protocols/jabber/jingle/rtp.c
@@ -220,7 +220,7 @@ jingle_rtp_stream_info_cb(PurpleMedia *m
 				session);
 
 		g_object_unref(session);
-	/* The same signal is emited *four* times in case of acceptance
+	/* The same signal is emitted *four* times in case of acceptance
 	 * by purple_media_stream_info() (stream acceptance, session
 	 * acceptance, participant acceptance, and conference acceptance).
 	 * We only react to the first one, where sid and name are given
diff --git a/libpurple/protocols/jabber/si.c b/libpurple/protocols/jabber/si.c
--- a/libpurple/protocols/jabber/si.c
+++ b/libpurple/protocols/jabber/si.c
@@ -804,7 +804,7 @@ jabber_si_connect_proxy_cb(JabberStream 
 			"jabber_si_xfer_connect_proxy_cb: got error, method: %d\n",
 			jsx->stream_method);
 		if (jsx->stream_method & STREAM_METHOD_IBB) {
-			/* if we previously tried bytestreams, we need to disble it. */
+			/* if we previously tried bytestreams, we need to disable it. */
 			if(jsx->stream_method & STREAM_METHOD_BYTESTREAMS) {
 				jsx->stream_method &= ~STREAM_METHOD_BYTESTREAMS;
 			}
@@ -1637,7 +1637,7 @@ static void jabber_si_xfer_xfer_init(Pur
 
 		/* we should maybe "remember" if bytestreams has failed before (in the
 			same session) with this JID, and only present IBB as an option to
-			avoid unnessesary timeout */
+			avoid unnecessary timeout */
 		/* maybe we should have an account option to always just try IBB
 			for people who know their firewalls are very restrictive */
 		if (jsx->stream_method & STREAM_METHOD_BYTESTREAMS) {
diff --git a/libpurple/protocols/jabber/tests/test_jabber_caps.c b/libpurple/protocols/jabber/tests/test_jabber_caps.c
--- a/libpurple/protocols/jabber/tests/test_jabber_caps.c
+++ b/libpurple/protocols/jabber/tests/test_jabber_caps.c
@@ -51,7 +51,7 @@ main(gint argc, gchar **argv) {
 	g_test_add_func("/jabber/caps/parse invalid nodes",
 	                test_jabber_caps_parse_invalid_nodes);
 
-	g_test_add_func("/jabber/caps/calulate from xmlnode",
+	g_test_add_func("/jabber/caps/calculate from xmlnode",
 	                test_jabber_caps_calculate_from_xmlnode);
 
 	return g_test_run();
diff --git a/libpurple/protocols/novell/nmconference.h b/libpurple/protocols/novell/nmconference.h
--- a/libpurple/protocols/novell/nmconference.h
+++ b/libpurple/protocols/novell/nmconference.h
@@ -25,7 +25,7 @@ typedef struct _NMConference NMConferenc
 
 #include "nmuserrecord.h"
 
-/* A blank GUID -- represents an uninstatiated conference */
+/* A blank GUID -- represents an uninstantiated conference */
 #define BLANK_GUID "[00000000-00000000-00000000-0000-0000]"
 
 /* This is how much of the conference GUIDs to compare when testing
diff --git a/libpurple/protocols/sametime/sametime.c b/libpurple/protocols/sametime/sametime.c
--- a/libpurple/protocols/sametime/sametime.c
+++ b/libpurple/protocols/sametime/sametime.c
@@ -97,7 +97,7 @@ static PurpleProtocol *my_protocol = NUL
 #define MW_CONNECT_STEPS  11
 
 
-/* stages of conciousness */
+/* stages of consciousness */
 #define MW_STATE_OFFLINE      "offline"
 #define MW_STATE_ACTIVE       "active"
 #define MW_STATE_AWAY         "away"
@@ -1125,7 +1125,7 @@ static void blist_sync(PurpleConnection 
     if(owner && purple_strequal(owner, acct_n))
        continue;
 
-    /* we actually are synching by this key as opposed to the group
+    /* we actually are syncing by this key as opposed to the group
        title, which can be different things in the st list */
     gname = purple_blist_node_get_string(gn, GROUP_KEY_NAME);
     if(! gname) gname = purple_group_get_name(grp);
@@ -2274,7 +2274,7 @@ static void mw_ft_opened(struct mwFileTr
 static void mw_ft_closed(struct mwFileTransfer *ft, guint32 code) {
   /*
     - get purple ft from client data in ft
-    - indicate rejection/cancelation/completion
+    - indicate rejection/cancellation/completion
     - free the file transfer itself
   */
 
@@ -2310,7 +2310,7 @@ static void mw_ft_recv(struct mwFileTran
 		       struct mwOpaque *data) {
   /*
     - get purple ft from client data in ft
-    - update transfered percentage
+    - update transferred percentage
     - if done, destroy the ft, disassociate from purple ft
   */
 
diff --git a/libpurple/protocols/zephyr/zephyr_html.c b/libpurple/protocols/zephyr/zephyr_html.c
--- a/libpurple/protocols/zephyr/zephyr_html.c
+++ b/libpurple/protocols/zephyr/zephyr_html.c
@@ -242,7 +242,7 @@ html_to_zephyr(const char *message)
 					}
 				}
 			} else {
-				/* Catch all for all unrecognized/misparsed <foo> tage */
+				/* Catch all for all unrecognized/misparsed <foo> tags */
 				g_string_append_c(frame->text, *message++);
 			}
 		} else if (*message == '@') {

diff --git a/libpurple/protocols/novell/novell.c b/libpurple/protocols/novell/novell.c
--- a/libpurple/protocols/novell/novell.c
+++ b/libpurple/protocols/novell/novell.c
@@ -1363,9 +1363,9 @@ static void
 	if (root_folder) {
 
 		/* Add sub-folders and contacts to sub-folders...
-		 * iterate throught the sub-folders in reverse order
-		 * because Purple adds the folders to the front -- so we
-		 * want to add the first folder last
+		 * iterate through the sub-folders in reverse order because
+		 * Purple adds the folders to the front -- so we want to add
+		 * the first folder last
 		 */
 		cnt = nm_folder_get_subfolder_count(root_folder);
 		for (i = cnt-1; i >= 0; i--) {
@@ -1558,23 +1558,24 @@ static void
 	g_free(name);
 }
 
 /* Send a join conference, the first item in the parms list is the
  * NMUser object and the second item is the conference to join.
  * This callback is passed to purple_request_action when we ask the
  * user if they want to join the conference.
  */
 static void
-_join_conference_cb(GSList * parms)
+_join_conference_cb(GSList *params)
 {
 	NMUser *user;
 	NMConference *conference;
 	NMERR_T rc = NM_OK;
 
-	if (parms == NULL || g_slist_length(parms) != 2)
+	if (params == NULL || g_slist_length(params) != 2) {
 		return;
-
-	user = g_slist_nth_data(parms, 0);
-	conference = g_slist_nth_data(parms, 1);
+	}
+
+	user = g_slist_nth_data(params, 0);
+	conference = g_slist_nth_data(params, 1);
 
 	if (user && conference) {
 		rc = nm_send_join_conference(user, conference,
@@ -1582,33 +1583,34 @@ static void
 		_check_for_disconnect(user, rc);
 	}
 
-	g_slist_free(parms);
+	g_slist_free(params);
 }
 
 /* Send a reject conference, the first item in the parms list is the
  * NMUser object and the second item is the conference to reject.
  * This callback is passed to purple_request_action when we ask the
  * user if they want to joing the conference.
  */
 static void
-_reject_conference_cb(GSList * parms)
+_reject_conference_cb(GSList *params)
 {
 	NMUser *user;
 	NMConference *conference;
 	NMERR_T rc = NM_OK;
 
-	if (parms == NULL || g_slist_length(parms) != 2)
+	if (params == NULL || g_slist_length(params) != 2) {
 		return;
-
-	user = g_slist_nth_data(parms, 0);
-	conference = g_slist_nth_data(parms, 1);
+	}
+
+	user = g_slist_nth_data(params, 0);
+	conference = g_slist_nth_data(params, 1);
 
 	if (user && conference) {
 		rc = nm_send_reject_conference(user, conference, NULL, NULL);
 		_check_for_disconnect(user, rc);
 	}
 
-	g_slist_free(parms);
+	g_slist_free(params);
 }
 
 static void
@@ -1913,7 +1915,7 @@ static void
 {
 	NMUserRecord *ur;
 	PurpleConnection *gc;
-	GSList *parms = NULL;
+	GSList *params = NULL;
 	const char *title = NULL;
 	const char *secondary = NULL;
 	const char *name = NULL;
@@ -1933,13 +1935,13 @@ static void
 							  name, purple_date_format_full(localtime(&gmt)));
 	secondary = _("Would you like to join the conversation?");
 
 	/* Set up parms list for the callbacks
 	 * We need to send the NMUser object and
 	 * the NMConference object to the callbacks
 	 */
-	parms = NULL;
-	parms = g_slist_append(parms, user);
-	parms = g_slist_append(parms, nm_event_get_conference(event));
+	params = NULL;
+	params = g_slist_append(params, user);
+	params = g_slist_append(params, nm_event_get_conference(event));
 
 	/* Prompt the user */
 	/* TODO: Would it be better to use purple_serv_got_chat_invite() here? */
@@ -1947,7 +1949,7 @@ static void
 	purple_request_action(gc, title, primary, secondary,
 						PURPLE_DEFAULT_ACTION_NONE,
 						purple_request_cpar_from_connection(gc),
-						parms, 2,
+						params, 2,
 						_("Yes"), G_CALLBACK(_join_conference_cb),
 						_("No"), G_CALLBACK(_reject_conference_cb));
 
@@ -1558,23 +1558,24 @@ static void
 }
 
-/* Send a join conference, the first item in the parms list is the
+/* Send a join conference, the first item in the params list is the
  * NMUser object and the second item is the conference to join.
  * This callback is passed to purple_request_action when we ask the
@@ -1582,33 +1583,34 @@ static void
 }
 
-/* Send a reject conference, the first item in the parms list is the
+/* Send a reject conference, the first item in the params list is the
  * NMUser object and the second item is the conference to reject.
  * This callback is passed to purple_request_action when we ask the
@@ -1933,13 +1935,13 @@ static void
 	secondary = _("Would you like to join the conversation?");
 
-	/* Set up parms list for the callbacks
+	/* Set up params list for the callbacks
 	 * We need to send the NMUser object and
 	 * the NMConference object to the callbacks